==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x06e4+ 1785-0x0ddd));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x040f+ 5633-0x1a0f));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x172d+ 3153-0x237c));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getValueOfSessionShadowingMode{(my $value=shift (@_));if ((
($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ((0x03e7+ 1425-0x0978));}elsif ((($value 
eq $DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue)))
{return ((0x0668+   6-0x066d));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0304+ 5182-0x1740));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x11eb+ 789-0x14ff));}return ((0x0d38+ 2079-0x1557));}return (
(0x02db+  40-0x0302));

==> nomachine-8.2.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x137f+ 496-0x156f));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x0d2c+ 6332-0x25e7));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x129b+ 4925-0x25d6));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getShadowingModeValue{(my $value=shift (@_));if ((($value 
eq $DesktopMode::ViewOnlyString)or ($value eq $DesktopMode::ViewOnlyValue))){
return ((0x0ab1+ 7002-0x260b));}elsif ((($value eq 
$DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue))){
return ((0x0503+ 8074-0x248c));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x1383+ 233-0x146a));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0ddb+ 5331-0x22ad));}return ((0x01cd+ 8124-0x2189));}return (
(0x053a+ 7587-0x22dc));
